@@ -23,9 +23,10 @@ import org.apache.spark.sql.catalyst.analysis.{UnresolvedAttribute, UnresolvedFu
 import org.apache.spark.sql.catalyst.expressions.{Alias, Ascending, AttributeReference, EqualTo, Expression, ExpressionEvalHelper, Literal, NullsLast, SortOrder}
 import org.apache.spark.sql.catalyst.parser.{ParseException, ParserInterface}
 import org.apache.spark.sql.catalyst.plans.logical.{Filter, LogicalPlan, OneRowRelation, Project, Sort}
+import org.apache.spark.sql.execution.command.CreateDataSourceTableAsSelectCommand
 import org.apache.spark.sql.execution.datasources.InsertIntoHadoopFsRelationCommand
 import org.apache.spark.sql.functions._
-import org.apache.spark.sql.hive.execution.InsertIntoHiveTable
+import org.apache.spark.sql.hive.execution.{CreateHiveTableAsSelectCommand, InsertIntoHiveTable, OptimizedCreateHiveTableAsSelectCommand}
 import org.apache.spark.sql.internal.{SQLConf, StaticSQLConf}
 import org.apache.spark.sql.types._
 
@@ -293,24 +294,24 @@ trait ZorderSuiteBase extends KyuubiSparkSQLExtensionTest with ExpressionEvalHel
             withSQLConf(
               "spark.sql.hive.convertMetastoreCtas" -> optimized,
               "spark.sql.hive.convertMetastoreParquet" -> optimized) {
-
-              withListener(
-                s"""
-                   |CREATE TABLE zorder_t2_$optimized STORED AS PARQUET
-                   |TBLPROPERTIES (
-                   | 'kyuubi.zorder.enabled' = '$enabled',
-                   | 'kyuubi.zorder.cols' = '$cols')
-                   |
-                   |SELECT $repartition * FROM
-                   |VALUES(1,'a',2,4D),(2,'b',3,6D) AS t(c1 ,c2 , c3, c4)
-                   |""".stripMargin) { write =>
-                if (optimized.toBoolean) {
-                  assert(write.isInstanceOf[InsertIntoHadoopFsRelationCommand])
-                } else {
-                  assert(write.isInstanceOf[InsertIntoHiveTable])
-                }
-                checkSort(write.query)
+              val df2 =
+                sql(
+                  s"""
+                     |CREATE TABLE zorder_t2_$optimized STORED AS PARQUET
+                     |TBLPROPERTIES (
+                     | 'kyuubi.zorder.enabled' = '$enabled',
+                     | 'kyuubi.zorder.cols' = '$cols')
+                     |
+                     |SELECT $repartition * FROM
+                     |VALUES(1,'a',2,4D),(2,'b',3,6D) AS t(c1 ,c2 , c3, c4)
+                     |""".stripMargin)
+              if (optimized.toBoolean) {
+                assert(df2.queryExecution.analyzed
+                  .isInstanceOf[OptimizedCreateHiveTableAsSelectCommand])
+              } else {
+                assert(df2.queryExecution.analyzed.isInstanceOf[CreateHiveTableAsSelectCommand])
               }
+              checkSort(df2.queryExecution.analyzed.children.head)
             }
           }
         }
@@ -332,19 +333,19 @@ trait ZorderSuiteBase extends KyuubiSparkSQLExtensionTest with ExpressionEvalHel
         assert(df1.queryExecution.analyzed.isInstanceOf[InsertIntoHadoopFsRelationCommand])
         checkSort(df1.queryExecution.analyzed.children.head)
 
-        withListener(
-          s"""
-             |CREATE TABLE zorder_t4 USING PARQUET
-             |TBLPROPERTIES (
-             | 'kyuubi.zorder.enabled' = '$enabled',
-             | 'kyuubi.zorder.cols' = '$cols')
-             |
-             |SELECT $repartition * FROM
-             |VALUES(1,'a',2,4D),(2,'b',3,6D) AS t(c1 ,c2 , c3, c4)
-             |""".stripMargin) { write =>
-          assert(write.isInstanceOf[InsertIntoHadoopFsRelationCommand])
-          checkSort(write.query)
-        }
+        val df2 =
+          sql(
+            s"""
+               |CREATE TABLE zorder_t4 USING PARQUET
+               |TBLPROPERTIES (
+               | 'kyuubi.zorder.enabled' = '$enabled',
+               | 'kyuubi.zorder.cols' = '$cols')
+               |
+               |SELECT $repartition * FROM
+               |VALUES(1,'a',2,4D),(2,'b',3,6D) AS t(c1 ,c2 , c3, c4)
+               |""".stripMargin)
+        assert(df2.queryExecution.analyzed.isInstanceOf[CreateDataSourceTableAsSelectCommand])
+        checkSort(df2.queryExecution.analyzed.children.head)
       }
     }
   }
@@ -372,10 +373,8 @@ trait ZorderSuiteBase extends KyuubiSparkSQLExtensionTest with ExpressionEvalHel
         val plan = Project(Seq(Alias(zorder, "c")()), OneRowRelation())
         spark.sessionState.analyzer.checkAnalysis(plan)
       }.getMessage
-      // before Spark 3.2.0 the null type catalog string is null, after Spark 3.2.0 it's void
-      // see https://github.com/apache/spark/pull/33437
-      assert(msg.contains("Unsupported z-order type:") &&
-        (msg.contains("null") || msg.contains("void")))
+      // SPARK-36224 (3.2): use Void as the type name of NullType
+      assert(msg.contains("Unsupported z-order type:") && msg.contains("void"))
     }
 
     checkZorderPlan(Zorder(Seq(Literal(null, NullType))))
