@@ -21,7 +21,7 @@ import org.apache.kyuubi.plugin.spark.authz.OperationType._
 import org.apache.kyuubi.plugin.spark.authz.serde._
 import org.apache.kyuubi.plugin.spark.authz.serde.FunctionType.{SYSTEM, TEMP}
 
-object FunctionCommands {
+object FunctionCommands extends CommandSpecs[FunctionCommandSpec] {
 
   val CreateFunction = {
     val cmd = "org.apache.spark.sql.execution.command.CreateFunctionCommand"
@@ -83,9 +83,9 @@ object FunctionCommands {
     FunctionCommandSpec(cmd, Seq(functionDesc), RELOADFUNCTION)
   }
 
-  val data: Array[FunctionCommandSpec] = Array(
+  override def specs: Seq[FunctionCommandSpec] = Seq(
     CreateFunction,
     DropFunction,
     DescribeFunction,
-    RefreshFunction).sortBy(_.classname)
+    RefreshFunction)
 }
