@@ -17,11 +17,18 @@
 
 package org.apache.kyuubi.service.authentication
 
+import java.security.Principal
+
 /**
  * This authentication provider allows any combination of username and password.
  */
-class AnonymousAuthenticationProviderImpl extends PasswdAuthenticationProvider {
+class AnonymousAuthenticationProviderImpl extends PasswdAuthenticationProvider
+  with TokenAuthenticationProvider {
   override def authenticate(user: String, password: String): Unit = {
     // no-op authentication
   }
+  override def authenticate(credential: TokenCredential): Principal = {
+    // no-op authentication
+    new BasicPrincipal("anonymous")
+  }
 }
