@@ -68,6 +68,21 @@ public class Utils {
   public static final Pattern KYUUBI_OPERATION_HINT_PATTERN =
       Pattern.compile("^__kyuubi_operation_result_(.*)__=(.*)", Pattern.CASE_INSENSITIVE);
 
+  public static final String CLIENT_IP_ADDRESS;
+
+  static {
+    String localIpAddress = null;
+    try {
+      localIpAddress = InetAddress.getLocalHost().getHostAddress();
+    } catch (UnknownHostException e) {
+      LOG.warn("Error getting Kyuubi local client IP address", e);
+    }
+    if (StringUtils.isBlank(localIpAddress)) {
+      localIpAddress = "unknown";
+    }
+    CLIENT_IP_ADDRESS = localIpAddress;
+  }
+
   static String getMatchedUrlPrefix(String uri) throws JdbcUriParseException {
     for (String urlPrefix : URL_PREFIX_LIST) {
       if (uri.startsWith(urlPrefix)) {
@@ -654,7 +669,6 @@ public class Utils {
         hadoopCredentialProviderAvailable = true;
       } catch (Exception exception) {
         LOG.warn("Hadoop credential provider is unavailable", exception);
-        throw new RuntimeException(exception);
       }
     }
     if (password == null && hadoopCredentialProviderAvailable) {
