@@ -20,6 +20,7 @@ package org.apache.kyuubi.server.http.authentication
 import java.security.PrivilegedAction
 import javax.servlet.http.{HttpServletRequest, HttpServletResponse}
 
+import com.codahale.metrics.jetty9.InstrumentedHandler
 import org.apache.hadoop.security.UserGroupInformation
 import org.eclipse.jetty.server.{Handler, Request}
 import org.eclipse.jetty.server.handler.HandlerWrapper
@@ -44,8 +45,8 @@ class KyuubiHttpAuthenticationFactory(conf: KyuubiConf) {
     new HttpHandlerWrapperFactory(ugi, kerberosEnabled)
 
   class HttpHandlerWrapperFactory(ugi: UserGroupInformation, kerberosEnabled: Boolean) {
-    def wrapHandler(handler: Handler): HandlerWrapper = {
-      new HandlerWrapper {
+    def wrapHandler(handler: Handler, metricPrefix: Option[String] = None): HandlerWrapper = {
+      val handlerWrapper = new HandlerWrapper {
         _handler = handler
 
         override def handle(
@@ -91,6 +92,14 @@ class KyuubiHttpAuthenticationFactory(conf: KyuubiConf) {
           handler.start()
         }
       }
+
+      (MetricsSystem.getMetricsRegistry, metricPrefix) match {
+        case (Some(metricRegistry), Some(prefix)) =>
+          val instrumentedHandler = new InstrumentedHandler(metricRegistry, prefix)
+          instrumentedHandler.setHandler(handlerWrapper)
+          instrumentedHandler
+        case _ => handlerWrapper
+      }
     }
   }
 }
