@@ -22,18 +22,22 @@ import org.eclipse.jetty.server.handler.{ContextHandlerCollection, ErrorHandler}
 import org.eclipse.jetty.util.component.LifeCycle
 import org.eclipse.jetty.util.thread.{QueuedThreadPool, ScheduledExecutorScheduler}
 
+import org.apache.kyuubi.Logging
 import org.apache.kyuubi.util.JavaUtils
 
 private[kyuubi] class JettyServer(
     server: Server,
     connector: ServerConnector,
-    rootHandler: ContextHandlerCollection) {
+    rootHandler: ContextHandlerCollection) extends Logging {
 
   def start(): Unit = synchronized {
     try {
       server.start()
       connector.start()
       server.addConnector(connector)
+      val localPort = connector.getLocalPort
+      require(localPort > 0, "Jetty server port should be positive, but got " + localPort)
+      _serverUri = connector.getHost + ":" + localPort
     } catch {
       case e: Exception =>
         stop()
@@ -49,7 +53,13 @@ private[kyuubi] class JettyServer(
       case _ =>
     }
   }
-  def getServerUri: String = connector.getHost + ":" + connector.getLocalPort
+
+  @volatile private var _serverUri: String = _
+  def getServerUri: String = Option(_serverUri).getOrElse {
+    val uri = connector.getHost + ":" + connector.getLocalPort
+    warn("Jetty server is not started yet, returning " + uri)
+    uri
+  }
 
   def addHandler(handler: Handler): Unit = synchronized {
     rootHandler.addHandler(handler)
